@@ -140,17 +140,16 @@ void output_footer()
     o(      "<div id=\"footer\">\n"
             "<hr />\n"
             "<div align=\"right\">\n"
-/*             "<p>\n" */
-/*             "\t<a href=\"http://validator.w3.org/check?uri=referer\">\n" */
-/*             "\t\t<img src=\"http://www.w3.org/Icons/valid-xhtml10\" alt=\"Valid XHTML 1.0 Transitional\" height=\"31\" width=\"88\" />\n" */
-/*             "\t</a>\n" */
-/*             "</p>\n" */
-            "<div><address>Powered by cgic.</address></div>\n"
-            "<div><address>Powered by SQLite3.</address></div>\n"
+            "<p>\n"
+            "\t<a href=\"http://validator.w3.org/check?uri=referer\">\n"
+            "\t\t<img src=\"%s/../img/valid-xhtml10.gif\" alt=\"Valid XHTML 1.0 Transitional\" height=\"31\" width=\"88\" />\n"
+            "\t</a>\n"
+            "</p>\n"
+            "<div><address>Powered by cgic &amp; SQLite3.</address></div>\n"
             "<div><address>Starbug1 version: %s. Copyright smeghead 2007 - 2008.</address></div>\n"
             "</div>\n"
             "</div>\n"
-            "</body>\n</html>\n", VERSION);
+            "</body>\n</html>\n", cgiScriptName, VERSION);
 }
 int cgiMain() {
     register_actions();
@@ -1399,7 +1398,7 @@ static void register_list_item(int id, char* name)
 }
 /**
  * 登録するaction。
- * 登録モード、編集モード、削除モードがある。
+ * 登録モード、編集モードがある。
  */
 void register_submit_action()
 {
@@ -1474,6 +1473,7 @@ void register_submit_action()
                         set_element_value(e, value_a);
                         /* 新しく選択肢を追加 */
                         register_list_item(et->id, value_a);
+                        strcat(value_a, "\t");
                     }
                     if ((cgiFormStringMultiple(name, &multi)) != cgiFormNotFound) {
                         int i = 0;
@@ -2070,9 +2070,9 @@ got_item:
                     o("\n");
                 }
                 o(      "\t\t];\n"
+                        "\t\tdocument.write('<canvas width=\"400\" height=\"300\" id=\"graph_%d\"></canvas>');\n"
                         "\t\t// -->\n"
-                        "\t\t</script>\n"
-                  "<canvas width=\"400\" height=\"300\" id=\"graph_%d\"></canvas>\n", et->id);
+                        "\t\t</script>\n", et->id);
                 o("</div>\n");
                 break;
         }
